@@ -31,7 +31,7 @@ def get_pc_contribution(evecs, evals):
     values are relative to each component and thus the sum may surpass 1."""
     n = 2
     pcs = []; relcontribs = []
-    contribs = (evals / np.max(evals))[:n]
+    contribs = (evals / np.sum(evals))[:n]
 
     for i in range(n): # Just two major components
         evec = np.abs(evecs[:, i])
